Codegen Module
==============

.. module:: beluga.codegen

Introduction
------------

Base Class Reference
--------------------

.. autofunction:: load_eqn_template

.. autofunction:: create_module

.. autofunction:: make_control_and_ham_fn

.. autofunction:: make_functions

.. autofunction:: compile_code_py

.. autofunction:: make_njit_fn

.. autofunction:: make_sympy_fn
